@@ -3,9 +3,11 @@ Abstraction for handling KNX/IP tunnels.
 
 Tunnels connect to KNX/IP devices directly via UDP and build a static UDP connection.
 """
+from __future__ import annotations
+
 import asyncio
 import logging
-from typing import TYPE_CHECKING, Callable, Optional
+from typing import TYPE_CHECKING, Callable
 
 from xknx.exceptions import CommunicationError, XKNXException
 from xknx.knxip import (
@@ -19,12 +21,9 @@ from xknx.knxip import (
 )
 from xknx.telegram import IndividualAddress, Telegram, TelegramDirection
 
-from .connect import Connect
-from .connectionstate import ConnectionState
 from .const import HEARTBEAT_RATE
-from .disconnect import Disconnect
 from .interface import Interface
-from .tunnelling import Tunnelling
+from .request_response import Connect, ConnectionState, Disconnect, Tunnelling
 from .udp_client import UDPClient
 
 if TYPE_CHECKING:
@@ -38,22 +37,19 @@ logger = logging.getLogger("xknx.log")
 class Tunnel(Interface):
     """Class for handling KNX/IP tunnels."""
 
-    # pylint: disable=too-many-instance-attributes
-
     def __init__(
         self,
-        xknx: "XKNX",
+        xknx: XKNX,
         gateway_ip: str,
         gateway_port: int,
         local_ip: str,
         local_port: int = 0,
         route_back: bool = False,
-        telegram_received_callback: Optional["TelegramCallbackType"] = None,
+        telegram_received_callback: TelegramCallbackType | None = None,
         auto_reconnect: bool = True,
         auto_reconnect_wait: int = 3,
     ):
         """Initialize Tunnel class."""
-        # pylint: disable=too-many-arguments
         self.xknx = xknx
         self.gateway_ip = gateway_ip
         self.gateway_port = gateway_port
@@ -67,14 +63,14 @@ class Tunnel(Interface):
 
         self._src_address = xknx.own_address
         self.sequence_number = 0
-        self.communication_channel: Optional[int] = None
+        self.communication_channel: int | None = None
         self.number_heartbeat_failed = 0
 
         self.auto_reconnect = auto_reconnect
         self.auto_reconnect_wait = auto_reconnect_wait
 
-        self._heartbeat_task: Optional[asyncio.Task[None]] = None
-        self._reconnect_task: Optional[asyncio.Task[None]] = None
+        self._heartbeat_task: asyncio.Task[None] | None = None
+        self._reconnect_task: asyncio.Task[None] | None = None
 
         self._is_reconnecting = False
 
