@@ -4,7 +4,9 @@ Module for Serialization and Deserialization of a KNX Connectionstate Response i
 Connectionstate requests are used to determine if a tunnel connection is still active and valid.
 With a connectionstate response the receiving party acknowledges the valid processing of the request.
 """
-from typing import TYPE_CHECKING, List
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from xknx.exceptions import CouldNotParseKNXIP
 
@@ -19,12 +21,11 @@ if TYPE_CHECKING:
 class ConnectionStateResponse(KNXIPBodyResponse):
     """Representation of a KNX Connection State Response."""
 
-    # pylint: disable=too-many-instance-attributes
     SERVICE_TYPE = KNXIPServiceType.CONNECTIONSTATE_RESPONSE
 
     def __init__(
         self,
-        xknx: "XKNX",
+        xknx: XKNX,
         communication_channel_id: int = 1,
         status_code: ErrorCode = ErrorCode.E_NO_ERROR,
     ):
@@ -51,10 +52,10 @@ class ConnectionStateResponse(KNXIPBodyResponse):
         pos = info_from_knx(raw)
         return pos
 
-    def to_knx(self) -> List[int]:
+    def to_knx(self) -> list[int]:
         """Serialize to KNX/IP raw data."""
 
-        def info_to_knx() -> List[int]:
+        def info_to_knx() -> list[int]:
             """Serialize information bytes."""
             info = []
             info.append(self.communication_channel_id)
