@@ -12,7 +12,6 @@ from abc import ABC, abstractmethod
 import logging
 from typing import (
     TYPE_CHECKING,
-    Any,
     Awaitable,
     Callable,
     Generic,
@@ -101,14 +100,14 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
         return self._value
 
     @value.setter
-    def value(self, value: Any) -> None:
+    def value(self, value: ValueType | None) -> None:
         """Set new value without creating a Telegram or calling after_update_cb. Raises ConversionError on invalid value."""
         if value is not None:
             # raises ConversionError on invalid value
             self.to_knx(value)
         self._value = value
 
-    async def update_value(self, value: Any) -> None:
+    async def update_value(self, value: ValueType | None) -> None:
         """Set new value without creating a Telegram. Awaits after_update_cb. Raises ConversionError on invalid value."""
         self.value = value
         if self.after_update_cb is not None:
@@ -156,7 +155,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
         """Convert current payload to value - to be implemented in derived class."""
 
     @abstractmethod
-    def to_knx(self, value: Any) -> DPTPayloadType:
+    def to_knx(self, value: ValueType) -> DPTPayloadType:
         """Convert value to payload - to be implemented in derived class."""
 
     async def process(self, telegram: Telegram, always_callback: bool = False) -> bool:
@@ -214,7 +213,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             )
             await self.xknx.telegrams.put(telegram)
 
-    async def set(self, value: Any, response: bool = False) -> None:
+    async def set(self, value: ValueType, response: bool = False) -> None:
         """Set new value."""
         if not self.initialized:
             logger.info(
@@ -289,7 +288,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             self.group_addr_str(),
         )
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         """Equal operator."""
         for key, value in self.__dict__.items():
             if key == "after_update_cb":
