@@ -13,10 +13,12 @@ It contains
 * and the payload (e.g. GroupValueWrite("12%")).
 
 """
-from enum import Enum
-from typing import Optional, Union
+from __future__ import annotations
 
-from .address import GroupAddress, IndividualAddress
+from datetime import datetime
+from enum import Enum
+
+from .address import GroupAddress, IndividualAddress, InternalGroupAddress
 from .apci import APCI
 
 
@@ -30,13 +32,13 @@ class TelegramDirection(Enum):
 class Telegram:
     """Class for KNX telegrams."""
 
-    # pylint: disable=too-few-public-methods
-
     def __init__(
         self,
-        destination_address: Union[GroupAddress, IndividualAddress] = GroupAddress(0),
+        destination_address: GroupAddress
+        | IndividualAddress
+        | InternalGroupAddress = GroupAddress(0),
         direction: TelegramDirection = TelegramDirection.OUTGOING,
-        payload: Optional[APCI] = None,
+        payload: APCI | None = None,
         source_address: IndividualAddress = IndividualAddress(0),
     ) -> None:
         """Initialize Telegram class."""
@@ -44,6 +46,7 @@ class Telegram:
         self.direction = direction
         self.payload = payload
         self.source_address = source_address
+        self.timestamp = datetime.now()
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -59,7 +62,17 @@ class Telegram:
 
     def __eq__(self, other: object) -> bool:
         """Equal operator."""
-        return bool(self.__dict__ == other.__dict__)
+        for key, value in self.__dict__.items():
+            if key == "timestamp":
+                continue
+            if key not in other.__dict__:
+                return False
+            if other.__dict__[key] != value:
+                return False
+        for key, value in other.__dict__.items():
+            if key not in self.__dict__:
+                return False
+        return True
 
     def __hash__(self) -> int:
         """Hash function."""
